# `testjjasinski` - My simple project

* Op1
* Op2
* Op3

# Install

```python
pip install testjjasinski
```

# Usage

```python
from testjjasisnki.m_mod_jjasinski import introduce as intro
>>> print(intro("Name", "Surname"))
Witaj Name Surname
```